aboutsummaryrefslogtreecommitdiffstats
path: root/src/math/bigint/bigint.h
diff options
context:
space:
mode:
authorlloyd <[email protected]>2012-08-01 13:46:46 +0000
committerlloyd <[email protected]>2012-08-01 13:46:46 +0000
commitafaac2c3668f0a0fced85649651d3d2ee9101a67 (patch)
tree8e012510e22065832af086b3c70973fe0820c988 /src/math/bigint/bigint.h
parent943c647e7d049a9b00261bbf34aa1443bca0ab02 (diff)
Rename the version of BigInt::data returning a mutable pointer
to BigInt::mutable_data. Update callers.
Diffstat (limited to 'src/math/bigint/bigint.h')
-rw-r--r--src/math/bigint/bigint.h12
1 files changed, 5 insertions, 7 deletions
diff --git a/src/math/bigint/bigint.h b/src/math/bigint/bigint.h
index baf2bfc71..f026e67f1 100644
--- a/src/math/bigint/bigint.h
+++ b/src/math/bigint/bigint.h
@@ -311,16 +311,14 @@ class BOTAN_DLL BigInt
size_t bits() const;
/**
* Return a pointer to the big integer word register
* @result a pointer to the start of the internal register of
* the integer value
*/
- word* data() { return &m_reg[0]; }
+ word* mutable_data() { return &m_reg[0]; }
/**
- * Return a pointer to the big integer word register
- * @result a pointer to the start of the internal register of
- * the integer value
+ * Return a const pointer to the register
+ * @result a pointer to the start of the internal register
*/
const word* data() const { return &m_reg[0]; }
@@ -311,16 +311,14 @@ class BOTAN_DLL BigInt
size_t bits() const;
/**
- * Return a pointer to the big integer word register
- * @result a pointer to the start of the internal register of
- * the integer value
+ * Return a mutable pointer to the register
+ * @result a pointer to the start of the internal register
*/